@@ -210,7 +210,8 @@ joint_probabilities <- function(object, response.cat, newdata = NULL, type = "pr
   pred.lower[is.na(pred.lower)] <- -object$rho$inf.value
   pred.upper[is.na(pred.upper)] <- object$rho$inf.value
   #################################
-  if(type == "cum.prob") pred.lower <- matrix(-object$rho$inf.value, ncol = ndim, nrow = nrow(pred.upper))
+  if(type == "cum.prob") pred.lower <- matrix(-object$rho$inf.value,
+                                              ncol = ndim, nrow = nrow(pred.upper))
   prob <- object$rho$link$F_multi(U = pred.upper, L = pred.lower,
                                   list_R = lapply(sigma, cov2cor))[ind]
   names(prob) <- rownames(y)[ind]
@@ -220,70 +221,85 @@ joint_probabilities <- function(object, response.cat, newdata = NULL, type = "pr
 
 prepare_newdata <- function(object, newdata, newoffset) {
   if (object$rho$function.name == "mvord") {
-      if (!all(object$rho$index %in% colnames(newdata)))
-        stop("Subject and outcome index do not appear in column names of newdata.")
+    if (!all(object$rho$index %in% colnames(newdata)))
+      stop("Subject and outcome index do not appear in column names of newdata.")
 
-      data.mvord <- mvord_data(newdata, object$rho$index, object$rho$response.name,
-        unique(c(object$rho$x.names, object$rho$weights.name)),
-                                 y.levels = object$rho$levels, response.names = object$rho$response.names)
+    data.mvord <- mvord_data(newdata, object$rho$index,
+                             object$rho$response.name,
+                             unique(c(object$rho$x.names, object$rho$weights.name)),
+                             y.levels = object$rho$levels,
+                             response.names = object$rho$response.names)
 
-      y <- data.mvord$y
-
-      x <- lapply(seq_len(object$rho$ndim), function(j) {
-        if(all(is.na(data.mvord$x[[j]]))){
-          tmp <- data.mvord$x[[j]]
-          tmp
-        } else {
-          rhs.form <- object$rho$formula
-          rhs.form[[2]] <- NULL
-          tmp <- model.matrix(rhs.form, data.mvord$x[[j]])
-          attribute <- attr(tmp, "assign")
-          tmp <- tmp[match(rownames(data.mvord$x[[j]]),rownames(tmp)),,drop=F]
-          rownames(tmp) <- rownames(data.mvord$x[[j]])
-          attr(tmp, "assign") <- attribute
-          tmp
-        }})
-        error.struct <- init_fun(object$error.struct, data.mvord, attr(object, "contrasts"))
+    y <- data.mvord$y
+    x <- lapply(seq_len(object$rho$ndim), function(j) {
+      if(all(is.na(data.mvord$x[[j]]))){
+        tmp <- data.mvord$x[[j]]
+      } else {
+        # rhs.form <- object$rho$formula #RH260820
+        # rhs.form[[2]] <- NULL #RH260820
+        rhs.form <- as.formula(paste0("~", paste(c(0,colnames(data.mvord$x[[j]])), collapse = " + "))) #RH260820 TODO 0 or 1
+        rhs.form <- as.formula(paste(as.character(object$rho$formula[-2]), collapse = " "))
+        new.rhs.form <- update(rhs.form, ~ . + 1)
+        tmp <-  suppressWarnings(model.matrix(new.rhs.form,
+                      model.frame(new.rhs.form,  data.mvord$x[[j]], na.action = function(x) x),
+                      contrasts.arg = attr(object, "contrasts")))
+        attribute <- attr(tmp, "assign")
+        intercept <- ifelse(attr(terms.formula(object$rho$formula), "intercept") == 1, TRUE, FALSE)
+        if (intercept == FALSE){
+          attribute <- attribute[-1]
+          tmp <- tmp[,-1, drop = FALSE]
+        }
+        tmp <- tmp[match(rownames(data.mvord$x[[j]]),rownames(tmp)), , drop=FALSE]
+        rownames(tmp) <- rownames(data.mvord$x[[j]])
+        attr(tmp, "assign") <- attribute
+      }
+      tmp
+    })
+    error.struct <- init_fun(object$error.struct, data.mvord, attr(object, "contrasts"))
   } else {
-     # if (is.null(object$rho$index)) stop("Estimated model uses MMO2, newdata is long format.")
-      if (!all(object$rho$y.names %in% colnames(newdata)))
-        stop("Response names in newdata do not match with the outcome names in the estimated model.")
-      y <- newdata[,object$rho$y.names]
-      y <- do.call("cbind.data.frame", lapply(seq_len(ncol(y)), function(j) ordered(y[,j], levels = object$rho$levels[[j]])))
-      colnames(y) <- object$rho$y.names
-      x <- lapply(seq_len(object$rho$ndim), function(j) {
-          rhs.form <- as.formula(paste(as.character(object$rho$formula[-2]), collapse = " "))
-          new.rhs.form <- update(rhs.form, ~ . + 1)
-          tmp <-  suppressWarnings(model.matrix(new.rhs.form,
-                  model.frame(new.rhs.form,  newdata, na.action = function(x) x),
-                  contrasts.arg = attr(object, "contrasts")))
-          attribute <- attr(tmp, "assign")
-          intercept <- ifelse(attr(terms.formula(object$rho$formula), "intercept") == 1, TRUE, FALSE)
-          if (intercept == FALSE){
-            attribute <- attribute[-1]
-            tmp <- tmp[,-1, drop = F]
-          }
-          attr(tmp, "assign") <- attribute
-          as.data.frame(tmp)
-        })
-      data.mvord <-  list(y = y, x = x)
-      error.struct <- init_fun(object$error.struct, data.mvord,
-         attr(object, "contrasts"))
+    # if (is.null(object$rho$index)) stop("Estimated model uses MMO2, newdata is long format.")
+    if (!all(object$rho$y.names %in% colnames(newdata)))
+      stop("Response names in newdata do not match with the outcome names in the estimated model.")
+    y <- newdata[,object$rho$y.names]
+    y <- do.call("cbind.data.frame", lapply(seq_len(ncol(y)), function(j)
+      ordered(y[,j], levels = object$rho$levels[[j]])))
+    colnames(y) <- object$rho$y.names
+    x <- lapply(seq_len(object$rho$ndim), function(j) {
+      rhs.form <- as.formula(paste(as.character(object$rho$formula[-2]), collapse = " "))
+      new.rhs.form <- update(rhs.form, ~ . + 1)
+      tmp <-  suppressWarnings(model.matrix(new.rhs.form,
+                                            model.frame(new.rhs.form,  newdata, na.action = function(x) x),
+                                            contrasts.arg = attr(object, "contrasts")))
+      attribute <- attr(tmp, "assign")
+      intercept <- ifelse(attr(terms.formula(object$rho$formula), "intercept") == 1, TRUE, FALSE)
+      if (intercept == FALSE){
+        attribute <- attribute[-1]
+        tmp <- tmp[,-1, drop = FALSE]
+      }
+      attr(tmp, "assign") <- attribute
+      as.data.frame(tmp)
+    })
+    data.mvord <-  list(y = y, x = x)
+    error.struct <- init_fun(object$error.struct, data.mvord,
+                             attr(object, "contrasts"))
   }
   if (is.null(newoffset)) {
-      newoffset <- lapply(seq_len(object$rho$ndim), function(j) {
-        rhs.form <- object$rho$formula
-        rhs.form[[2]] <- NULL
-        mf <- model.frame(rhs.form, as.data.frame(data.mvord$x[[j]]),
-                         na.action = function(x) x)
-        mf[is.na(mf)] <- 0
-        if (is.null(model.offset(mf))) {
-          ofs <- double(NROW(y))
-        } else {
-          ofs <- model.offset(mf)
-        }
-        ofs
-     })
+    newoffset <- lapply(seq_len(object$rho$ndim), function(j) {
+      rhs.form <- object$rho$formula
+      rhs.form[[2]] <- NULL
+      newdata_tmp <- switch(object$rho$function.name,
+                            "mvord" = data.mvord$x[[j]],
+                            "mvord2" = newdata)
+      mf <- model.frame(rhs.form, newdata_tmp,
+                        na.action = function(x) x)
+      mf[is.na(mf)] <- 0
+      if (is.null(model.offset(mf))) {
+        ofs <- double(NROW(y))
+      } else {
+        ofs <- model.offset(mf)
+      }
+      ofs
+    })
   }
   return(list(error.struct = error.struct, y = y, x = x, offset = newoffset))
 }
@@ -299,11 +315,11 @@ make_Xcat <- function(object, y, x) {
   if (object$rho$p > 0) {
     for (j in seq_len(ndim)) {
       B2 <- 1 * (col(matrix(0, nrow(y), ncat[j])) ==
-            c(unclass(y[, j])))
+                   c(unclass(y[, j])))
       mf <- do.call("cbind", lapply(as.data.frame(x[[j]]),
-        function(x) B2 * x))
-      XcatL[[j]] <- mf[,-(ncat[j] * (seq_len(object$rho$p) - 1) + 1), drop = F]
-      XcatU[[j]] <- mf[,-(ncat[j] * seq_len(object$rho$p)), drop = F]
+                                    function(x) B2 * x))
+      XcatL[[j]] <- mf[,-(ncat[j] * (seq_len(object$rho$p) - 1) + 1), drop = FALSE]
+      XcatU[[j]] <- mf[,-(ncat[j] * seq_len(object$rho$p)), drop = FALSE]
     }
   }
   list(U = XcatU, L = XcatL)
@@ -343,7 +359,7 @@ marg_pred_prob_fun <- function(object, y, x, offset, stddevs, ind) {
     th_l - xbeta_l - offset[[j]]
   })/stddevs
   prob <- object$rho$link$F_uni(pred.upper) -
-     object$rho$link$F_uni(pred.lower)
+    object$rho$link$F_uni(pred.lower)
   prob <- prob[ind, ]
   colnames(prob) <- object$rho$y.names
   rownames(prob) <- rownames(y)[ind]
@@ -353,22 +369,22 @@ marg_pred_prob_fun <- function(object, y, x, offset, stddevs, ind) {
 marg_pred_allprob_fun <- function(object, y, x, offset, stddevs, ind) {
   betatilde <- bdiag(object$rho$constraints) %*% object$beta
   probs <- lapply(seq_len(object$rho$ndim), function(j){
-      pr <- sapply(seq_len(object$rho$ncat[j]), function(k){
-        ytmp <- y[,j]
-        ytmp[seq_along(ytmp)] <- levels(ytmp)[k]
-        dim(ytmp)  <- c(length(ytmp),1)
-        Xcat <- make_Xcat(object, ytmp, x[j])
-        th_u <- c(object$theta[[j]], object$rho$inf.value)[ytmp[, 1]]
-        xbeta_u <- as.double(Xcat$U[[1]] %*% betatilde[object$rho$indjbeta[[j]]])
-        pred.upper <- (th_u - xbeta_u - offset[[j]])/stddevs[,j]
-        th_l <- c(-object$rho$inf.value, object$theta[[j]])[ytmp[, 1]]
-        xbeta_l <- as.double(Xcat$L[[1]] %*% betatilde[object$rho$indjbeta[[j]]])
-        pred.lower <- (th_l - xbeta_l - offset[[j]])/stddevs[, j]
-        object$rho$link$F_uni(pred.upper) - object$rho$link$F_uni(pred.lower)
-      })[ind, ]
-      colnames(pr) <- levels(object$rho$y[, j])
-      rownames(pr) <- rownames(y)[ind]
-      pr
+    pr <- sapply(seq_len(object$rho$ncat[j]), function(k){
+      ytmp <- y[,j]
+      ytmp[seq_along(ytmp)] <- levels(ytmp)[k]
+      dim(ytmp)  <- c(length(ytmp),1)
+      Xcat <- make_Xcat(object, ytmp, x[j])
+      th_u <- c(object$theta[[j]], object$rho$inf.value)[ytmp[, 1]]
+      xbeta_u <- as.double(Xcat$U[[1]] %*% betatilde[object$rho$indjbeta[[j]]])
+      pred.upper <- (th_u - xbeta_u - offset[[j]])/stddevs[,j]
+      th_l <- c(-object$rho$inf.value, object$theta[[j]])[ytmp[, 1]]
+      xbeta_l <- as.double(Xcat$L[[1]] %*% betatilde[object$rho$indjbeta[[j]]])
+      pred.lower <- (th_l - xbeta_l - offset[[j]])/stddevs[, j]
+      object$rho$link$F_uni(pred.upper) - object$rho$link$F_uni(pred.lower)
+    })[ind, ]
+    colnames(pr) <- levels(object$rho$y[, j])
+    rownames(pr) <- rownames(y)[ind]
+    pr
   })
   names(probs) <- object$rho$y.names
   return(probs)
@@ -415,20 +431,20 @@ pred_prob_fun <- function(object, y, x, offset, stddevs, sigma) {
   return(prob)
 }
 pred_cumprob_fun <-  function(object, y, x, offset, stddevs, sigma) {
-    Xcat <- make_Xcat(object, y, x)
-    betatilde <- bdiag(object$rho$constraints) %*% object$beta
-    pred.upper  <- sapply(seq_len(object$rho$ndim), function(j) {
-      th_u <- c(object$theta[[j]], object$rho$inf.value)[y[, j]]
-      xbeta_u <- as.double(Xcat$U[[j]] %*% betatilde[object$rho$indjbeta[[j]]])
-      th_u - xbeta_u - offset[[j]]
-    })/stddevs
-    pred.upper[is.na(pred.upper)] <- object$rho$inf.value
-    pred.lower <- matrix(-object$rho$inf.value, ncol = object$rho$ndim,
-      nrow = nrow(pred.upper))
-    cum.prob <- object$rho$link$F_multi(U = pred.upper, L = pred.lower,
-                list_R = lapply(sigma, cov2cor))
-    names(cum.prob) <- rownames(y)
-    return(cum.prob)
+  Xcat <- make_Xcat(object, y, x)
+  betatilde <- bdiag(object$rho$constraints) %*% object$beta
+  pred.upper  <- sapply(seq_len(object$rho$ndim), function(j) {
+    th_u <- c(object$theta[[j]], object$rho$inf.value)[y[, j]]
+    xbeta_u <- as.double(Xcat$U[[j]] %*% betatilde[object$rho$indjbeta[[j]]])
+    th_u - xbeta_u - offset[[j]]
+  })/stddevs
+  pred.upper[is.na(pred.upper)] <- object$rho$inf.value
+  pred.lower <- matrix(-object$rho$inf.value, ncol = object$rho$ndim,
+                       nrow = nrow(pred.upper))
+  cum.prob <- object$rho$link$F_multi(U = pred.upper, L = pred.lower,
+                                      list_R = lapply(sigma, cov2cor))
+  names(cum.prob) <- rownames(y)
+  return(cum.prob)
 }
 
 pred_class_fun <-  function(object, y, x, offset, stddevs, sigma) {
@@ -444,7 +460,7 @@ pred_class_fun <-  function(object, y, x, offset, stddevs, sigma) {
       if (i %% 100 == 0)  cat('Computed probabilities for', i, 'out of', nrow(cmbn),'combinations\n')
       ###############################################
       ytmp <- sapply(seq_len(ndim),
-        function(j) object$rho$levels[[j]][cmbn[i,j]])
+                     function(j) object$rho$levels[[j]][cmbn[i,j]])
       ytmp <- matrix(ytmp, ncol = ndim, nrow = nrow(y), byrow = TRUE)
       ytmp <-cbind.data.frame(lapply(seq_len(object$rho$ndim), function(j){
         if (!all(ytmp[,j] %in% c(NA, levels(y[,j]))))  stop("response.cat are different from the categories in the original data set")
@@ -465,7 +481,7 @@ pred_class_fun <-  function(object, y, x, offset, stddevs, sigma) {
       pred.upper[is.na(pred.upper)] <- object$rho$inf.value
       ############################################
       object$rho$link$F_multi(U = pred.upper, L = pred.lower,
-                       list_R = lapply(sigma, cov2cor))
+                              list_R = lapply(sigma, cov2cor))
     })
     ind.max <- apply(probs,1,which.max)
     class <- cmbn.labels[ind.max,]
